class WebExporter: Exporter {

    static let crosswordStudioUrl: String =
            "https://www.crosswordstudio.app/puzzles/upload"

    var controller: ExportWindowController!

    //export to local folder
    func export(_ document: Document, to url: URL) throws {

        let writer = DocumentWriter()
        let puzzleJson = writer.toJson(document)

        if puzzleJson != nil {

            if !FileManager.default.fileExists(atPath: url.path) {
                try FileManager.default.createDirectory(at: url, withIntermediateDirectories: false)
            }

            var jsonUrl = url
            jsonUrl.appendPathComponent("puzzle.js")
            try puzzleJson!.write(to: jsonUrl)

            var indexUrl = url
            indexUrl.appendPathComponent("index.html")
            var indexPath = "web/crossword/index"
            if(document.isWordSearch()) {
                indexPath = "web/wordsearch/index"
            }
            let indexHtml = Bundle.main.url(forResource: indexPath, withExtension: "html");
            try FileManager.default.copyItem(at: indexHtml!, to: indexUrl);
    
        }
    }

    //export to web
    func export(_ document: Document) throws {

        let writer = DocumentWriter()
        let puzzleJson = writer.toJson(document)

        if puzzleJson != nil {
            let url = URL(string: WebExporter.crosswordStudioUrl)!
            var request = URLRequest(url: url)

            request.setValue(Constants.XSecretKey, forHTTPHeaderField: "X-Secret")
            request.setValue("text/plain", forHTTPHeaderField: "Content-Type")

            request.httpMethod = "POST"
            request.httpBody = puzzleJson!

            controller.showUploadProgress(self)
            let task = URLSession.shared.dataTask(with: request) { data, response, error in

                if error != nil {
                    DispatchQueue.main.async {
                        self.controller.showUploadLink(self, nil)
                    }
                    return
                }
                let httpResponse = response as! HTTPURLResponse
                DispatchQueue.main.async {
                    if httpResponse.statusCode == 200 {
                        let puzzleId = String(decoding: data!, as: UTF8.self)
                        self.controller.showUploadLink(self, puzzleId)
                    } else {
                        self.controller.showUploadLink(self, nil)
                    }
                }

            }
            task.resume()
        }

    }

    func fileExtensions() -> Array<String> {
        []
    }
}
